@@ -5,7 +5,7 @@
 #include "gdesktop-enums-types.h"
 #include "cc-background-item.h"
 
-/* enumerations from "/usr/include/gsettings-desktop-schemas/gdesktop-enums.h" */
+/* enumerations from "/home/rmatos/Source/git.gnome.org/install/include/gsettings-desktop-schemas/gdesktop-enums.h" */
 GType
 g_desktop_proxy_mode_get_type (void)
 {
@@ -290,6 +290,51 @@ g_desktop_location_accuracy_level_get_type (void)
   }
   return etype;
 }
+GType
+g_desktop_touchpad_scroll_method_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { G_DESKTOP_TOUCHPAD_SCROLL_METHOD_DISABLED, "G_DESKTOP_TOUCHPAD_SCROLL_METHOD_DISABLED", "disabled" },
+      { G_DESKTOP_TOUCHPAD_SCROLL_METHOD_EDGE_SCROLLING, "G_DESKTOP_TOUCHPAD_SCROLL_METHOD_EDGE_SCROLLING", "edge-scrolling" },
+      { G_DESKTOP_TOUCHPAD_SCROLL_METHOD_TWO_FINGER_SCROLLING, "G_DESKTOP_TOUCHPAD_SCROLL_METHOD_TWO_FINGER_SCROLLING", "two-finger-scrolling" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GDesktopTouchpadScrollMethod", values);
+  }
+  return etype;
+}
+GType
+g_desktop_touchpad_handedness_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { G_DESKTOP_TOUCHPAD_HANDEDNESS_RIGHT, "G_DESKTOP_TOUCHPAD_HANDEDNESS_RIGHT", "right" },
+      { G_DESKTOP_TOUCHPAD_HANDEDNESS_LEFT, "G_DESKTOP_TOUCHPAD_HANDEDNESS_LEFT", "left" },
+      { G_DESKTOP_TOUCHPAD_HANDEDNESS_MOUSE, "G_DESKTOP_TOUCHPAD_HANDEDNESS_MOUSE", "mouse" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GDesktopTouchpadHandedness", values);
+  }
+  return etype;
+}
+GType
+g_desktop_device_send_events_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { G_DESKTOP_DEVICE_SEND_EVENTS_ENABLED, "G_DESKTOP_DEVICE_SEND_EVENTS_ENABLED", "enabled" },
+      { G_DESKTOP_DEVICE_SEND_EVENTS_DISABLED, "G_DESKTOP_DEVICE_SEND_EVENTS_DISABLED", "disabled" },
+      { G_DESKTOP_DEVICE_SEND_EVENTS_DISABLED_ON_EXTERNAL_MOUSE, "G_DESKTOP_DEVICE_SEND_EVENTS_DISABLED_ON_EXTERNAL_MOUSE", "disabled-on-external-mouse" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GDesktopDeviceSendEvents", values);
+  }
+  return etype;
+}
 
 /* enumerations from "cc-background-item.h" */
 GType
