@@ -81,7 +81,6 @@ struct _CcDisplayPanelPrivate
   GtkWidget *rotate_left_button;
   GtkWidget *upside_down_button;
   GtkWidget *rotate_right_button;
-  GtkWidget *apply_button;
   GtkWidget *dialog;
   GtkWidget *config_grid;
 
@@ -391,9 +390,6 @@ on_screen_changed (CcDisplayPanel *panel)
   GtkSizeGroup *sizegroup;
   GList *sorted_outputs = NULL, *l;
 
-  if (priv->dialog)
-    gtk_dialog_response (GTK_DIALOG (priv->dialog), GTK_RESPONSE_NONE);
-
   gnome_rr_screen_refresh (priv->screen, NULL);
 
   current = gnome_rr_config_new_current (priv->screen, NULL);
@@ -1140,7 +1136,7 @@ update_apply_button (CcDisplayPanel *panel)
   if (!gnome_rr_config_applicable (priv->current_configuration,
                                    priv->screen, NULL))
     {
-      gtk_widget_set_sensitive (priv->apply_button, FALSE);
+      gtk_dialog_set_response_sensitive (GTK_DIALOG (priv->dialog), GTK_RESPONSE_ACCEPT, FALSE);
       return;
     }
 
@@ -1192,7 +1188,7 @@ update_apply_button (CcDisplayPanel *panel)
 
   g_object_unref (current_configuration);
 
-  gtk_widget_set_sensitive (priv->apply_button, !config_equal);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (priv->dialog), GTK_RESPONSE_ACCEPT, !config_equal);
 }
 
 static void
@@ -1335,38 +1331,15 @@ paint_background (FooScrollArea *area,
                   cairo_t       *cr)
 {
   GdkRectangle viewport;
-  GtkWidget *widget;
-  GtkStyleContext *context;
-  GdkRGBA fg, bg;
-
-  widget = GTK_WIDGET (area);
 
   foo_scroll_area_get_viewport (area, &viewport);
-  context = gtk_widget_get_style_context (widget);
-  gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &fg);
-  gtk_style_context_get_background_color (context, GTK_STATE_FLAG_NORMAL, &bg);
-
-  cairo_set_source_rgba (cr,
-                         (fg.red + bg.red) / 2,
-                         (fg.green + bg.green) / 2,
-                         (fg.blue + bg.blue) / 2,
-                         (fg.alpha + bg.alpha) / 2);
 
+  cairo_set_source_rgba (cr, 0, 0, 0, 0.4);
   cairo_rectangle (cr,
                    viewport.x, viewport.y,
                    viewport.width, viewport.height);
-
-  cairo_fill_preserve (cr);
-
   foo_scroll_area_add_input_from_fill (area, cr, on_canvas_event, NULL);
-
-  cairo_set_source_rgba (cr,
-                         0.7 * bg.red,
-                         0.7 * bg.green,
-                         0.7 * bg.blue,
-                         0.7 * bg.alpha);
-
-  cairo_stroke (cr);
+  cairo_fill (cr);
 }
 
 static void
@@ -1530,18 +1503,17 @@ show_arrange_displays_dialog (GtkButton      *button,
   GtkWidget *content_area, *area, *vbox, *label;
   gint response;
 
-  priv->dialog = g_object_new (GTK_TYPE_DIALOG, "use-header-bar", TRUE, NULL);
+  /* Title of displays dialog when multiple monitors are present. */
+  priv->dialog = gtk_dialog_new_with_buttons (_("Arrange Combined Displays"),
+                                              GTK_WINDOW (cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (panel)))),
+                                              GTK_DIALOG_MODAL | GTK_DIALOG_USE_HEADER_BAR,
+                                              _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                              _("_Apply"), GTK_RESPONSE_ACCEPT,
+                                              NULL);
   g_signal_connect (priv->dialog, "notify::has-toplevel-focus",
                     G_CALLBACK (dialog_toplevel_focus_changed), panel);
-  gtk_window_set_title (GTK_WINDOW (priv->dialog), _("Arrange Combined Displays"));
-  gtk_window_set_transient_for (GTK_WINDOW (priv->dialog),
-                                GTK_WINDOW (cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (panel)))));
-  gtk_window_set_modal (GTK_WINDOW (priv->dialog), TRUE);
-  gtk_dialog_add_button (GTK_DIALOG (priv->dialog), _("_Cancel"),
-                         GTK_RESPONSE_CANCEL);
-  priv->apply_button = gtk_dialog_add_button (GTK_DIALOG (priv->dialog), _("_Apply"),
-                                              GTK_RESPONSE_ACCEPT);
-  gtk_widget_set_sensitive (priv->apply_button, FALSE);
+  gtk_dialog_set_default_response (GTK_DIALOG (priv->dialog), GTK_RESPONSE_ACCEPT);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (priv->dialog), GTK_RESPONSE_ACCEPT, FALSE);
 
   content_area = gtk_dialog_get_content_area (GTK_DIALOG (priv->dialog));
 
@@ -1572,13 +1544,17 @@ show_arrange_displays_dialog (GtkButton      *button,
   response = gtk_dialog_run (GTK_DIALOG (priv->dialog));
   if (response == GTK_RESPONSE_ACCEPT)
     apply_current_configuration (panel);
-  else if (response != GTK_RESPONSE_NONE)
+  else if (response == GTK_RESPONSE_NONE)
+    {
+      /* panel is being destroyed */
+      return;
+    }
+  else
     {
       /* re-read the previous configuration */
       on_screen_changed (panel);
     }
 
-  priv->apply_button = NULL;
   gtk_widget_destroy (priv->dialog);
   priv->dialog = NULL;
 }
@@ -1658,15 +1634,13 @@ list_box_item (const gchar *title,
 
   label = gtk_label_new (title);
   gtk_container_add (GTK_CONTAINER (item), label);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
-  gtk_widget_set_size_request (label, 230, -1);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 
   label = gtk_label_new (subtitle);
   gtk_container_add (GTK_CONTAINER (item), label);
   gtk_style_context_add_class (gtk_widget_get_style_context (label), GTK_STYLE_CLASS_DIM_LABEL);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
-  gtk_widget_set_size_request (label, 230, -1);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 
   gtk_container_add (GTK_CONTAINER (row), item);
@@ -1902,8 +1876,7 @@ res_combo_changed (GtkComboBox    *combo,
   GtkTreeModel *res_model;
   GtkTreeIter iter;
   GnomeRRMode *mode;
-  gint x, y, width, height, i;
-  GnomeRROutputInfo **outputs;
+  gint x, y, width, height;
 
   res_model = gtk_combo_box_get_model (combo);
 
@@ -1916,17 +1889,7 @@ res_combo_changed (GtkComboBox    *combo,
       width = gnome_rr_mode_get_width (mode);
       height = gnome_rr_mode_get_height (mode);
 
-      if (gnome_rr_config_get_clone (priv->current_configuration))
-        {
-          outputs = gnome_rr_config_get_outputs (priv->current_configuration);
-          for (i = 0; outputs[i]; i++)
-            gnome_rr_output_info_set_geometry (outputs[i], x, y, width, height);
-        }
-      else
-        {
-          gnome_rr_output_info_set_geometry (priv->current_output, x, y, width, height);
-        }
-
+      gnome_rr_output_info_set_geometry (priv->current_output, x, y, width, height);
       update_apply_button (panel);
     }
 }
@@ -1973,20 +1936,16 @@ show_setup_dialog (CcDisplayPanel *panel)
   output = gnome_rr_screen_get_output_by_name (priv->screen,
                                                gnome_rr_output_info_get_name (priv->current_output));
 
-
-  priv->dialog = g_object_new (GTK_TYPE_DIALOG, "use-header-bar", TRUE, NULL);
+  priv->dialog = gtk_dialog_new_with_buttons (gnome_rr_output_info_get_display_name (priv->current_output),
+                                              GTK_WINDOW (cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (panel)))),
+                                              GTK_DIALOG_MODAL | GTK_DIALOG_USE_HEADER_BAR,
+                                              _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                              _("_Apply"), GTK_RESPONSE_ACCEPT,
+                                              NULL);
   g_signal_connect (priv->dialog, "notify::has-toplevel-focus",
                     G_CALLBACK (dialog_toplevel_focus_changed), panel);
-  gtk_window_set_title (GTK_WINDOW (priv->dialog),
-                        gnome_rr_output_info_get_display_name (priv->current_output));
-  gtk_window_set_transient_for (GTK_WINDOW (priv->dialog),
-                                GTK_WINDOW (cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (panel)))));
-  gtk_window_set_modal (GTK_WINDOW (priv->dialog), TRUE);
-  gtk_dialog_add_button (GTK_DIALOG (priv->dialog), _("_Cancel"),
-                         GTK_RESPONSE_CANCEL);
-  priv->apply_button = gtk_dialog_add_button (GTK_DIALOG (priv->dialog),
-                                              _("_Apply"), GTK_RESPONSE_ACCEPT);
-  gtk_widget_set_sensitive (priv->apply_button, FALSE);
+  gtk_dialog_set_default_response (GTK_DIALOG (priv->dialog), GTK_RESPONSE_ACCEPT);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG (priv->dialog), GTK_RESPONSE_ACCEPT, FALSE);
   gtk_window_set_resizable (GTK_WINDOW (priv->dialog), FALSE);
 
   content_area = gtk_dialog_get_content_area (GTK_DIALOG (priv->dialog));
@@ -2111,10 +2070,9 @@ show_setup_dialog (CcDisplayPanel *panel)
   gtk_widget_set_halign (label, GTK_ALIGN_START);
 
   /* resolution combo box */
-  res_model = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
-  priv->res_combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (res_model));
-  g_object_unref (res_model);
+  res_model = gtk_list_store_new (2, G_TYPE_STRING, GNOME_TYPE_RR_MODE);
   renderer = gtk_cell_renderer_text_new ();
+  priv->res_combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (res_model));
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->res_combo), renderer, TRUE);
   gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (priv->res_combo), renderer, "text", 0);
   g_signal_connect (priv->res_combo, "changed", G_CALLBACK (res_combo_changed),
@@ -2297,7 +2255,12 @@ show_setup_dialog (CcDisplayPanel *panel)
 
       apply_current_configuration (panel);
     }
-  else if (response != GTK_RESPONSE_NONE)
+  else if (response == GTK_RESPONSE_NONE)
+    {
+      /* panel is being destroyed */
+      return;
+    }
+  else
     {
       /* changes cancelled, so re-read the current configuration */
       on_screen_changed (panel);
@@ -2306,7 +2269,6 @@ show_setup_dialog (CcDisplayPanel *panel)
   priv->rotate_left_button = NULL;
   priv->rotate_right_button = NULL;
   priv->res_combo = NULL;
-  priv->apply_button = NULL;
   gtk_widget_destroy (priv->dialog);
   priv->dialog = NULL;
 }
