@@ -184,7 +184,7 @@ cc_sharing_panel_dispose (GObject *object)
 static const char *
 cc_sharing_panel_get_help_uri (CcPanel *panel)
 {
-  return "help:gnome-help/prefs-sharing";
+  return "help:gnome-help/settings-sharing";
 }
 
 static void
@@ -478,7 +478,7 @@ cc_sharing_panel_add_folder (GtkListBox     *box,
 {
   CcSharingPanelPrivate *priv = self->priv;
   GtkWidget *dialog;
-  gchar *folder = NULL;
+  gchar *folder;
   gboolean matching = FALSE;
   GList *rows, *l;
 
@@ -492,8 +492,7 @@ cc_sharing_panel_add_folder (GtkListBox     *box,
                                         _("_Open"), GTK_RESPONSE_ACCEPT,
                                         NULL);
   gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), FALSE);
-  if (gtk_dialog_run (GTK_DIALOG (dialog)) != GTK_RESPONSE_ACCEPT)
-    goto bail;
+  gtk_dialog_run (GTK_DIALOG (dialog));
 
   gtk_widget_hide (dialog);
 
@@ -1046,22 +1045,19 @@ static gboolean
 cc_sharing_panel_check_schema_available (CcSharingPanel *self,
                                          const gchar *schema_id)
 {
-  const gchar * const* schema_list;
+  GSettingsSchemaSource *source;
+  GSettingsSchema *schema;
 
-  if (schema_id == NULL)
+  source = g_settings_schema_source_get_default ();
+  if (!source)
     return FALSE;
 
-  schema_list = g_settings_list_schemas ();
+  schema = g_settings_schema_source_lookup (source, schema_id, TRUE);
+  if (!schema)
+    return FALSE;
 
-  while (*schema_list)
-    {
-      if (g_str_equal (*schema_list, schema_id))
-        return TRUE;
-
-      schema_list++;
-    }
-
-  return FALSE;
+  g_settings_schema_unref (schema);
+  return TRUE;
 }
 
 static void
