@@ -34,6 +34,7 @@
 #include <polkit/polkit.h>
 #include <act/act.h>
 #include <libgd/gd-notification.h>
+#include <cairo-gobject.h>
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #include <libgnome-desktop/gnome-languages.h>
@@ -46,6 +47,8 @@
 
 #include "um-editable-button.h"
 #include "um-editable-combo.h"
+#include "um-user-image.h"
+#include "um-cell-renderer-user-image.h"
 
 #include "um-account-dialog.h"
 #include "cc-language-chooser.h"
@@ -58,6 +61,8 @@
 
 #include "cc-common-language.h"
 
+#include "um-realm-manager.h"
+
 #define USER_ACCOUNTS_PERMISSION "org.gnome.controlcenter.user-accounts.administration"
 
 CC_PANEL_REGISTER (CcUserPanel, cc_user_panel)
@@ -67,6 +72,7 @@ CC_PANEL_REGISTER (CcUserPanel, cc_user_panel)
 
 struct _CcUserPanelPrivate {
         ActUserManager *um;
+        GCancellable  *cancellable;
         GtkBuilder *builder;
         GtkWidget *notification;
 
@@ -92,7 +98,6 @@ get_widget (CcUserPanelPrivate *d, const char *name)
 
 enum {
         USER_COL,
-        FACE_COL,
         NAME_COL,
         USER_ROW_COL,
         TITLE_COL,
@@ -101,6 +106,44 @@ enum {
         NUM_USER_LIST_COLS
 };
 
+typedef struct {
+        CcUserPanel *self;
+        GCancellable *cancellable;
+        gchar *login;
+} AsyncDeleteData;
+
+static void
+async_delete_data_free (AsyncDeleteData *data)
+{
+        g_object_unref (data->self);
+        g_object_unref (data->cancellable);
+        g_free (data->login);
+        g_slice_free (AsyncDeleteData, data);
+}
+
+static void
+show_error_dialog (CcUserPanelPrivate *d,
+                   const gchar *message,
+                   GError *error)
+{
+        GtkWidget *dialog;
+
+        dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)),
+                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_USE_HEADER_BAR,
+                                         GTK_MESSAGE_ERROR,
+                                         GTK_BUTTONS_CLOSE,
+                                         "%s", message);
+
+        if (error != NULL) {
+                g_dbus_error_strip_remote_error (error);
+                gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+                                                          "%s", error->message);
+        }
+
+        g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+        gtk_window_present (GTK_WINDOW (dialog));
+}
+
 static ActUser *
 get_selected_user (CcUserPanelPrivate *d)
 {
@@ -149,7 +192,6 @@ user_added (ActUserManager *um, ActUser *user, CcUserPanelPrivate *d)
         GtkListStore *store;
         GtkTreeIter iter;
         GtkTreeIter dummy;
-        GdkPixbuf *pixbuf;
         gchar *text, *title;
         GtkTreeSelection *selection;
         gint sort_key;
@@ -164,7 +206,6 @@ user_added (ActUserManager *um, ActUser *user, CcUserPanelPrivate *d)
         store = GTK_LIST_STORE (model);
         selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (widget));
 
-        pixbuf = render_user_icon (user, UM_ICON_STYLE_FRAME | UM_ICON_STYLE_STATUS, 48);
         text = get_name_col_str (user);
 
         if (act_user_get_uid (user) == getuid ()) {
@@ -178,14 +219,12 @@ user_added (ActUserManager *um, ActUser *user, CcUserPanelPrivate *d)
 
         gtk_list_store_set (store, &iter,
                             USER_COL, user,
-                            FACE_COL, pixbuf,
                             NAME_COL, text,
                             USER_ROW_COL, TRUE,
                             TITLE_COL, NULL,
                             HEADING_ROW_COL, FALSE,
                             SORT_KEY_COL, sort_key,
                             -1);
-        g_object_unref (pixbuf);
         g_free (text);
 
         if (sort_key == 1 &&
@@ -301,7 +340,6 @@ user_changed (ActUserManager *um, ActUser *user, CcUserPanelPrivate *d)
         GtkTreeModel *model;
         GtkTreeIter iter;
         ActUser *current;
-        GdkPixbuf *pixbuf;
         char *text;
 
         tv = (GtkTreeView *)get_widget (d, "list-treeview");
@@ -312,15 +350,12 @@ user_changed (ActUserManager *um, ActUser *user, CcUserPanelPrivate *d)
         do {
                 gtk_tree_model_get (model, &iter, USER_COL, &current, -1);
                 if (current == user) {
-                        pixbuf = render_user_icon (user, UM_ICON_STYLE_FRAME | UM_ICON_STYLE_STATUS, 48);
                         text = get_name_col_str (user);
 
                         gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                                             USER_COL, user,
-                                            FACE_COL, pixbuf,
                                             NAME_COL, text,
                                             -1);
-                        g_object_unref (pixbuf);
                         g_free (text);
                         g_object_unref (current);
 
@@ -407,22 +442,10 @@ delete_user_done (ActUserManager    *manager,
 
         error = NULL;
         if (!act_user_manager_delete_user_finish (manager, res, &error)) {
-                if (!g_error_matches (error, ACT_USER_MANAGER_ERROR, ACT_USER_MANAGER_ERROR_PERMISSION_DENIED)) {
-                        GtkWidget *dialog;
+                if (!g_error_matches (error, ACT_USER_MANAGER_ERROR,
+                                      ACT_USER_MANAGER_ERROR_PERMISSION_DENIED))
+                        show_error_dialog (d, _("Failed to delete user"), error);
 
-                        dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)),
-                                                         GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                         GTK_MESSAGE_ERROR,
-                                                         GTK_BUTTONS_CLOSE,
-                                                         _("Failed to delete user"));
-
-                        gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                                                  "%s", error->message);
-
-                        g_signal_connect (G_OBJECT (dialog), "response",
-                                          G_CALLBACK (gtk_widget_destroy), NULL);
-                        gtk_window_present (GTK_WINDOW (dialog));
-                }
                 g_error_free (error);
         }
 }
@@ -465,8 +488,174 @@ delete_user_response (GtkWidget         *dialog,
 }
 
 static void
-delete_user (GtkButton *button, CcUserPanelPrivate *d)
+enterprise_user_revoked (GObject *source,
+                         GAsyncResult *result,
+                         gpointer user_data)
 {
+        AsyncDeleteData *data = user_data;
+        CcUserPanelPrivate *d = data->self->priv;
+        UmRealmCommon *common = UM_REALM_COMMON (source);
+        GError *error = NULL;
+
+        if (g_cancellable_is_cancelled (data->cancellable)) {
+                async_delete_data_free (data);
+                return;
+        }
+
+        um_realm_common_call_change_login_policy_finish (common, result, &error);
+        if (error != NULL) {
+                show_error_dialog (d, _("Failed to revoke remotely managed user"), error);
+                g_error_free (error);
+        }
+
+        async_delete_data_free (data);
+}
+
+static UmRealmCommon *
+find_matching_realm (UmRealmManager *realm_manager, const gchar *login)
+{
+        UmRealmCommon *common = NULL;
+        GList *realms, *l;
+
+        realms = um_realm_manager_get_realms (realm_manager);
+        for (l = realms; l != NULL; l = g_list_next (l)) {
+                const gchar * const *permitted_logins;
+                gint i;
+
+                common = um_realm_object_get_common (l->data);
+                permitted_logins = um_realm_common_get_permitted_logins (common);
+                for (i = 0; permitted_logins[i] != NULL; i++) {
+                        if (g_strcmp0 (permitted_logins[i], login) == 0)
+                                break;
+                }
+
+                if (permitted_logins[i] != NULL)
+                        break;
+
+                g_clear_object (&common);
+        }
+        g_list_free_full (realms, g_object_unref);
+
+        return common;
+}
+
+static void
+realm_manager_found (GObject *source,
+                     GAsyncResult *result,
+                     gpointer user_data)
+{
+        AsyncDeleteData *data = user_data;
+        CcUserPanelPrivate *d = data->self->priv;
+        UmRealmCommon *common;
+        UmRealmManager *realm_manager;
+        const gchar *add[1];
+        const gchar *remove[2];
+        GVariant *options;
+        GError *error = NULL;
+
+        if (g_cancellable_is_cancelled (data->cancellable)) {
+                async_delete_data_free (data);
+                return;
+        }
+
+        realm_manager = um_realm_manager_new_finish (result, &error);
+        if (error != NULL) {
+                show_error_dialog (d, _("Failed to revoke remotely managed user"), error);
+                g_error_free (error);
+                async_delete_data_free (data);
+                return;
+        }
+
+        /* Find matching realm */
+        common = find_matching_realm (realm_manager, data->login);
+        if (common == NULL) {
+                /* The realm was probably left */
+                async_delete_data_free (data);
+                return;
+        }
+
+        /* Remove the user from permitted logins */
+        g_debug ("Denying future login for: %s", data->login);
+
+        add[0] = NULL;
+        remove[0] = data->login;
+        remove[1] = NULL;
+
+        options = g_variant_new_array (G_VARIANT_TYPE ("{sv}"), NULL, 0);
+        um_realm_common_call_change_login_policy (common, "",
+                                                  add, remove, options,
+                                                  data->cancellable,
+                                                  enterprise_user_revoked,
+                                                  data);
+
+        g_object_unref (common);
+}
+
+static void
+enterprise_user_uncached (GObject           *source,
+                          GAsyncResult      *res,
+                          gpointer           user_data)
+{
+        AsyncDeleteData *data = user_data;
+        CcUserPanelPrivate *d = data->self->priv;
+        ActUserManager *manager = ACT_USER_MANAGER (source);
+        GError *error = NULL;
+
+        if (g_cancellable_is_cancelled (data->cancellable)) {
+                async_delete_data_free (data);
+                return;
+        }
+
+        act_user_manager_uncache_user_finish (manager, res, &error);
+        if (error == NULL) {
+                /* Find realm manager */
+                um_realm_manager_new (d->cancellable, realm_manager_found, data);
+        }
+        else {
+                show_error_dialog (d, _("Failed to revoke remotely managed user"), error);
+                g_error_free (error);
+                async_delete_data_free (data);
+        }
+}
+
+static void
+delete_enterprise_user_response (GtkWidget          *dialog,
+                                 gint                response_id,
+                                 gpointer            user_data)
+{
+        CcUserPanel *self = UM_USER_PANEL (user_data);
+        CcUserPanelPrivate *d = self->priv;
+        AsyncDeleteData *data;
+        ActUser *user;
+
+        gtk_widget_destroy (dialog);
+
+        if (response_id != GTK_RESPONSE_ACCEPT) {
+                return;
+        }
+
+        user = get_selected_user (self->priv);
+
+        data = g_slice_new (AsyncDeleteData);
+        data->self = g_object_ref (self);
+        data->cancellable = g_object_ref (d->cancellable);
+        data->login = g_strdup (act_user_get_user_name (user));
+
+        g_object_unref (user);
+
+        /* Uncache the user account from the accountsservice */
+        g_debug ("Uncaching remote user: %s", data->login);
+
+        act_user_manager_uncache_user_async (d->um, data->login,
+                                             data->cancellable,
+                                             enterprise_user_uncached,
+                                             data);
+}
+
+static void
+delete_user (GtkButton *button, CcUserPanel *self)
+{
+        CcUserPanelPrivate *d = self->priv;
         ActUser *user;
         GtkWidget *dialog;
 
@@ -496,7 +685,7 @@ delete_user (GtkButton *button, CcUserPanelPrivate *d)
                 g_signal_connect (dialog, "response",
                                   G_CALLBACK (gtk_widget_destroy), NULL);
         }
-        else {
+        else if (act_user_is_local_account (user)) {
                 dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)),
                                                  0,
                                                  GTK_MESSAGE_QUESTION,
@@ -518,6 +707,24 @@ delete_user (GtkButton *button, CcUserPanelPrivate *d)
                 g_signal_connect (dialog, "response",
                                   G_CALLBACK (delete_user_response), d);
         }
+        else {
+                dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)),
+                                                 0,
+                                                 GTK_MESSAGE_QUESTION,
+                                                 GTK_BUTTONS_NONE,
+                                                 _("Are you sure you want to revoke remotely managed %s's account?"),
+                                                 get_real_or_user_name (user));
+
+                gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+                                        _("_Delete"), GTK_RESPONSE_ACCEPT,
+                                        _("_Cancel"), GTK_RESPONSE_CANCEL,
+                                        NULL);
+
+                gtk_window_set_icon_name (GTK_WINDOW (dialog), "system-users");
+
+                g_signal_connect (dialog, "response",
+                                  G_CALLBACK (delete_enterprise_user_response), self);
+        }
 
         g_signal_connect (dialog, "close",
                           G_CALLBACK (gtk_widget_destroy), NULL);
@@ -664,20 +871,15 @@ show_user (ActUser *user, CcUserPanelPrivate *d)
 {
         GtkWidget *image;
         GtkWidget *label;
-        GdkPixbuf *pixbuf;
-        gchar *lang, *text;
+        gchar *lang, *text, *name;
         GtkWidget *widget;
-        GtkTreeModel *model;
-        GtkTreeIter iter;
         gboolean show, enable;
         ActUser *current;
 
-        pixbuf = render_user_icon (user, UM_ICON_STYLE_NONE, 48);
         image = get_widget (d, "user-icon-image");
-        gtk_image_set_from_pixbuf (GTK_IMAGE (image), pixbuf);
+        um_user_image_set_user (UM_USER_IMAGE (image), user);
         image = get_widget (d, "user-icon-image2");
-        gtk_image_set_from_pixbuf (GTK_IMAGE (image), pixbuf);
-        g_object_unref (pixbuf);
+        um_user_image_set_user (UM_USER_IMAGE (image), user);
 
         um_photo_dialog_set_user (d->photo_dialog, user);
 
@@ -699,22 +901,21 @@ show_user (ActUser *user, CcUserPanelPrivate *d)
         g_signal_handlers_unblock_by_func (widget, autologin_changed, d);
         gtk_widget_set_sensitive (widget, get_autologin_possible (user));
 
-        widget = get_widget (d, "account-language-combo");
-        model = um_editable_combo_get_model (UM_EDITABLE_COMBO (widget));
-        cc_common_language_add_user_languages (model);
+        widget = get_widget (d, "account-language-button");
 
+        name = NULL;
         lang = g_strdup (act_user_get_language (user));
         if ((!lang || *lang == '\0') && act_user_get_uid (user) == getuid ()) {
                 lang = cc_common_language_get_current_language ();
                 act_user_set_language (user, lang);
         }
 
-        if (cc_common_language_get_iter_for_language (model, lang, &iter)) {
-                um_editable_combo_set_active_iter (UM_EDITABLE_COMBO (widget), &iter);
-        } else {
-                um_editable_combo_set_active_iter (UM_EDITABLE_COMBO (widget), NULL);
+        if (lang && *lang != '\0') {
+                name = gnome_get_language_from_locale (lang, NULL);
         }
+        um_editable_button_set_text (UM_EDITABLE_BUTTON (widget), name);
         g_free (lang);
+        g_free (name);
 
         /* Fingerprint: show when self, possible, and local account */
         widget = get_widget (d, "account-fingerprint-button");
@@ -726,7 +927,7 @@ show_user (ActUser *user, CcUserPanelPrivate *d)
         gtk_widget_set_visible (widget, show);
 
         /* Autologin: show when local account */
-        widget = get_widget (d, "autologin-switch");
+        widget = get_widget (d, "autologin-box");
         label = get_widget (d, "autologin-label");
         show = act_user_is_local_account (user);
         gtk_widget_set_visible (widget, show);
@@ -813,48 +1014,6 @@ account_type_changed (UmEditableCombo    *combo,
         g_object_unref (user);
 }
 
-static void
-language_response (GtkDialog         *dialog,
-                   gint               response_id,
-                   CcUserPanelPrivate *d)
-{
-        GtkWidget *combo;
-        ActUser *user;
-        gchar *lang = NULL;
-        GtkTreeModel *model;
-        GtkTreeIter iter;
-
-        user = get_selected_user (d);
-
-        combo = get_widget (d, "account-language-combo");
-        model = um_editable_combo_get_model (UM_EDITABLE_COMBO (combo));
-
-        if (response_id == GTK_RESPONSE_OK) {
-                lang = g_strdup (cc_language_chooser_get_language (GTK_WIDGET (dialog)));
-        }
-
-        if (lang != NULL) {
-                act_user_set_language (user, lang);
-        }
-        else {
-                lang = g_strdup (act_user_get_language (user));
-        }
-
-        if (cc_common_language_get_iter_for_language (model, lang, &iter)) {
-                um_editable_combo_set_active_iter (UM_EDITABLE_COMBO (combo), &iter);
-        }
-        else {
-                um_editable_combo_set_active_iter (UM_EDITABLE_COMBO (combo), NULL);
-        }
-
-        g_free (lang);
-
-        gtk_widget_hide (GTK_WIDGET (dialog));
-        gtk_widget_set_sensitive (combo, TRUE);
-
-        g_object_unref (user);
-}
-
 static void
 restart_now (CcUserPanelPrivate *d)
 {
@@ -875,7 +1034,7 @@ restart_now (CcUserPanelPrivate *d)
 }
 
 static void
-show_restart_notification (CcUserPanelPrivate *d, gchar *locale)
+show_restart_notification (CcUserPanelPrivate *d, const gchar *locale)
 {
         GtkWidget *box;
         GtkWidget *label;
@@ -919,37 +1078,58 @@ show_restart_notification (CcUserPanelPrivate *d, gchar *locale)
 }
 
 static void
-language_changed (UmEditableCombo    *combo,
-                  CcUserPanelPrivate *d)
+language_response (GtkDialog         *dialog,
+                   gint               response_id,
+                   CcUserPanelPrivate *d)
 {
-        GtkTreeModel *model;
-        GtkTreeIter iter;
-        gchar *lang;
-        const gchar *current_language;
+        GtkWidget *button;
         ActUser *user;
+        const gchar *lang, *account_language;
+        gchar *current_language;
+        gchar *name = NULL;
         gboolean self_selected;
 
-        if (!um_editable_combo_get_active_iter (combo, &iter))
-                 return;
+        if (response_id != GTK_RESPONSE_OK) {
+                gtk_widget_hide (GTK_WIDGET (dialog));
+                return;
+        }
+
+        user = get_selected_user (d);
+        account_language = act_user_get_language (user);
+        self_selected = act_user_get_uid (user) == geteuid ();
+
+        lang = cc_language_chooser_get_language (GTK_WIDGET (dialog));
+        if (lang) {
+                if (g_strcmp0 (lang, account_language) != 0) {
+                        act_user_set_language (user, lang);
+
+                        /* Do not show the notification if the locale is already used. */
+                        current_language = gnome_normalize_locale (setlocale (LC_MESSAGES, NULL));
+                        if (self_selected && g_strcmp0 (lang, current_language) != 0)
+                                show_restart_notification (d, lang);
+                        g_free (current_language);
+                }
+
+                button = get_widget (d, "account-language-button");
+                name = gnome_get_language_from_locale (lang, NULL);
+                um_editable_button_set_text (UM_EDITABLE_BUTTON (button), name);
+                g_free (name);
+        }
+
+        g_object_unref (user);
+
+        gtk_widget_hide (GTK_WIDGET (dialog));
+}
+
+static void
+change_language (GtkButton *button,
+                 CcUserPanelPrivate *d)
+{
+        const gchar *current_language;
+        ActUser *user;
 
         user = get_selected_user (d);
         current_language = act_user_get_language (user);
-        self_selected = act_user_get_uid (user) == geteuid ();
-
-        model = um_editable_combo_get_model (combo);
-
-        gtk_tree_model_get (model, &iter, 0, &lang, -1);
-
-        if (lang) {
-                if (g_strcmp0 (lang, current_language) != 0) {
-                        act_user_set_language (user, lang);
-
-                        if (self_selected)
-                                show_restart_notification (d, lang);
-                }
-                g_free (lang);
-                goto out;
-        }
 
         if (d->language_chooser) {
 		cc_language_chooser_clear_filter (d->language_chooser);
@@ -969,9 +1149,7 @@ language_changed (UmEditableCombo    *combo,
         if (current_language && *current_language != '\0')
                 cc_language_chooser_set_language (d->language_chooser, current_language);
         gtk_window_present (GTK_WINDOW (d->language_chooser));
-        gtk_widget_set_sensitive (GTK_WIDGET (combo), FALSE);
 
-out:
         g_object_unref (user);
 }
 
@@ -1246,10 +1424,10 @@ on_permission_changed (GPermission *permission,
 
         if (is_authorized || self_selected) {
                 gtk_widget_show (get_widget (d, "user-icon-button"));
-                gtk_widget_hide (get_widget (d, "user-icon-nonbutton"));
+                gtk_widget_hide (get_widget (d, "user-icon-image"));
 
-                um_editable_combo_set_editable (UM_EDITABLE_COMBO (get_widget (d, "account-language-combo")), TRUE);
-                remove_unlock_tooltip (get_widget (d, "account-language-combo"));
+                um_editable_button_set_editable (UM_EDITABLE_BUTTON (get_widget (d, "account-language-button")), TRUE);
+                remove_unlock_tooltip (get_widget (d, "account-language-button"));
 
                 um_editable_button_set_editable (UM_EDITABLE_BUTTON (get_widget (d, "account-password-button")), TRUE);
                 remove_unlock_tooltip (get_widget (d, "account-password-button"));
@@ -1259,10 +1437,10 @@ on_permission_changed (GPermission *permission,
         }
         else {
                 gtk_widget_hide (get_widget (d, "user-icon-button"));
-                gtk_widget_show (get_widget (d, "user-icon-nonbutton"));
+                gtk_widget_show (get_widget (d, "user-icon-image"));
 
-                um_editable_combo_set_editable (UM_EDITABLE_COMBO (get_widget (d, "account-language-combo")), FALSE);
-                add_unlock_tooltip (get_widget (d, "account-language-combo"));
+                um_editable_button_set_editable (UM_EDITABLE_BUTTON (get_widget (d, "account-language-button")), FALSE);
+                add_unlock_tooltip (get_widget (d, "account-language-button"));
 
                 um_editable_button_set_editable (UM_EDITABLE_BUTTON (get_widget (d, "account-password-button")), FALSE);
                 add_unlock_tooltip (get_widget (d, "account-password-button"));
@@ -1361,8 +1539,9 @@ update_padding (GtkWidget *button, GtkWidget *label)
 }
 
 static void
-setup_main_window (CcUserPanelPrivate *d)
+setup_main_window (CcUserPanel *self)
 {
+        CcUserPanelPrivate *d = self->priv;
         GtkWidget *userlist;
         GtkTreeModel *model;
         GtkListStore *store;
@@ -1381,7 +1560,6 @@ setup_main_window (CcUserPanelPrivate *d)
         userlist = get_widget (d, "list-treeview");
         store = gtk_list_store_new (NUM_USER_LIST_COLS,
                                     ACT_TYPE_USER,
-                                    GDK_TYPE_PIXBUF,
                                     G_TYPE_STRING,
                                     G_TYPE_BOOLEAN,
                                     G_TYPE_STRING,
@@ -1412,9 +1590,9 @@ setup_main_window (CcUserPanelPrivate *d)
         d->other_iter = NULL;
 
         column = gtk_tree_view_column_new ();
-        cell = gtk_cell_renderer_pixbuf_new ();
+        cell = um_cell_renderer_user_image_new (userlist);
         gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (column), cell, FALSE);
-        gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (column), cell, "pixbuf", FACE_COL);
+        gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (column), cell, "user", USER_COL);
         gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (column), cell, "visible", USER_ROW_COL);
         cell = gtk_cell_renderer_text_new ();
         g_object_set (cell, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
@@ -1440,9 +1618,9 @@ setup_main_window (CcUserPanelPrivate *d)
         g_signal_connect (button, "clicked", G_CALLBACK (add_user), d);
 
         button = get_widget (d, "remove-user-toolbutton");
-        g_signal_connect (button, "clicked", G_CALLBACK (delete_user), d);
+        g_signal_connect (button, "clicked", G_CALLBACK (delete_user), self);
 
-        button = get_widget (d, "user-icon-nonbutton");
+        button = get_widget (d, "user-icon-image");
         add_unlock_tooltip (button);
 
         button = get_widget (d, "full-name-entry");
@@ -1454,8 +1632,8 @@ setup_main_window (CcUserPanelPrivate *d)
         button = get_widget (d, "account-password-button");
         g_signal_connect (button, "start-editing", G_CALLBACK (change_password), d);
 
-        button = get_widget (d, "account-language-combo");
-        g_signal_connect (button, "editing-done", G_CALLBACK (language_changed), d);
+        button = get_widget (d, "account-language-button");
+        g_signal_connect (button, "start-editing", G_CALLBACK (change_language), d);
 
         button = get_widget (d, "autologin-switch");
         g_signal_connect (button, "notify::active", G_CALLBACK (autologin_changed), d);
@@ -1518,11 +1696,14 @@ cc_user_panel_init (CcUserPanel *self)
         type = um_editable_button_get_type ();
         type = cc_editable_entry_get_type ();
         type = um_editable_combo_get_type ();
+        type = um_user_image_get_type ();
+        type = um_cell_renderer_user_image_get_type ();
 
         gtk_widget_set_size_request (GTK_WIDGET (self), -1, 350);
 
         d->builder = gtk_builder_new ();
         d->um = act_user_manager_get_default ();
+        d->cancellable = g_cancellable_new ();
 
         error = NULL;
         if (!gtk_builder_add_from_resource (d->builder,
@@ -1539,7 +1720,7 @@ cc_user_panel_init (CcUserPanel *self)
         d->main_box = get_widget (d, "accounts-vbox");
         gtk_container_add (GTK_CONTAINER (self), get_widget (d, "overlay"));
         d->history_dialog = um_history_dialog_new ();
-        setup_main_window (d);
+        setup_main_window (self);
 
         context = gtk_widget_get_style_context (get_widget (d, "list-scrolledwindow"));
         gtk_style_context_set_junction_sides (context, GTK_JUNCTION_BOTTOM);
@@ -1552,6 +1733,9 @@ cc_user_panel_dispose (GObject *object)
 {
         CcUserPanelPrivate *priv = UM_USER_PANEL (object)->priv;
 
+        g_cancellable_cancel (priv->cancellable);
+        g_clear_object (&priv->cancellable);
+
         if (priv->um) {
                 g_signal_handlers_disconnect_by_data (priv->um, priv);
                 priv->um = NULL;
